@@ -34,7 +34,8 @@
   {% endcall %}
 
   {% if file_format == 'hudi' %}
-        {{ adapter.hudi_merge_table(target_relation, sql, unique_key, partition_by, custom_location) }}
+        {%- set hudi_options = config.get('hudi_options', default={}) -%}
+        {{ adapter.hudi_merge_table(target_relation, sql, unique_key, partition_by, custom_location, hudi_options) }}
         {% set build_sql = "select * from " + target_relation.schema + "." + target_relation.identifier + " limit 1 "%}
   {% elif file_format == 'iceberg' %}
         {{ adapter.iceberg_write(target_relation, sql, unique_key, partition_by, custom_location, strategy, table_properties) }}
